@@ -18,7 +18,7 @@
 
 extern crate chrono;
 extern crate chrono_tz;
-extern crate dmntk_common;
+pub extern crate dmntk_common;
 #[macro_use]
 extern crate lazy_static;
 extern crate regex;
