@@ -16,10 +16,8 @@
 
 //! implementation of `FEEL` name.
 
-use {
-  dmntk_common::{Feelify, Jsonify, Stringify},
-  std::ops::Deref,
-};
+use dmntk_common::{Feelify, Jsonify, Stringify};
+use std::ops::Deref;
 
 /// Common type definition for optional name.
 pub type OptName = Option<Name>;
